Struct svc_agent::AgentId [−][src]
pub struct AgentId { /* fields omitted */ }Expand description
Agent identifier.
It consists of a string label and AccountId and must be unique.
Multiple agents may use the same AccountId, e.g. multiple instances
of the same service or multiple devices or browser tabs of an end user, but the label
must be different across them. An agent identifier has to be unique, otherwise it gets
disconnected by the broker. You can safely use the same label if
AccountId is different.
Implementations
impl AgentId[src]
impl AgentId[src]pub fn new(label: &str, account_id: AccountId) -> Self[src]
pub fn new(label: &str, account_id: AccountId) -> Self[src]Builds an AgentId.
Arguments
-
label– a unique string to identify the particular agent. For example the name of a service instance or a user device. -
account_id– the account identifier of an agent.
Example
let agent_id1 = AgentId::new("instance01", AccountId::new("service_name", "svc.example.org")); let agent_id2 = AgentId::new("web", AccountId::new("user_name", "usr.example.org"));
pub fn label(&self) -> &str[src]