Struct svc_agent::SharedGroup [−][src]
pub struct SharedGroup { /* fields omitted */ }Expand description
A group of agents which shares a subscription. Commonly used for balancing requests over a group of instances of some service.
Implementations
impl SharedGroup[src]
impl SharedGroup[src]pub fn new(label: &str, account_id: AccountId) -> Self[src]
pub fn new(label: &str, account_id: AccountId) -> Self[src]Builds a SharedGroup.
Arguments
label– shared group label to distinct it from the others if there are any.account_id– service account id. All the group’s participant agents must have the same.
Example
let_account_id = AccountId::new("service_name", "svc.example.org"); let shared_group = SharedGroup::new("loadbalancer", account_id);